<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2023 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Helper\ModuleHelper;
use Joomla\CMS\Uri\Uri;

/**
 * Variables
 *
 * @var \Joomla\Registry\Registry $params
 */

// Require library + register autoloader
require_once JPATH_ADMINISTRATOR . '/components/com_eventbooking/libraries/rad/bootstrap.php';

// Require module helper
require_once __DIR__ . '/helper.php';

$document = Factory::getDocument();
$user     = Factory::getUser();
$config   = EventbookingHelper::getConfig();
$baseUrl  = Uri::base(true);

// Load component language
EventbookingHelper::loadLanguage();

$itemId = (int) $params->get('item_id', 0) ?: EventbookingHelper::getItemid();

$rows = modEBAdvSliderHelper::getData($params);

$numberEvents = count($rows);

$sliderSettings = [
	'type'       => 'loop',
	'perPage'    => min($params->get('number_items', 3), $numberEvents),
	'speed'      => (int) $params->get('speed', 300),
	'autoplay'   => (bool) $params->get('autoplay', 1),
	'arrows'     => (bool) $params->get('arrows', 1),
	'pagination' => (bool) $params->get('pagination', 1),
	'gap'        => $params->get('gap', '1em'),
];

$numberItemsXs = $params->get('number_items_xs', 0);
$numberItemsSm = $params->get('number_items_sm', 0);
$numberItemsMd = $params->get('number_items_md', 0);
$numberItemsLg = $params->get('number_items_lg', 0);

if ($numberItemsXs && $numberEvents)
{
	$sliderSettings['breakpoints'][576]['perPage'] = min($numberItemsXs, $numberEvents);
}

if ($numberItemsSm && $numberEvents)
{
	$sliderSettings['breakpoints'][768]['perPage'] = min($numberItemsSm, $numberEvents);
}

if ($numberItemsMd && $numberEvents)
{
	$sliderSettings['breakpoints'][992]['perPage'] = min($numberItemsMd, $numberEvents);
}

if ($numberItemsLg && $numberEvents)
{
	$sliderSettings['breakpoints'][1200]['perPage'] = min($numberItemsLg, $numberEvents);
}

require ModuleHelper::getLayoutPath('mod_eb_advslider', 'default');
